SolidLintsPlugin class

An analysis server plugin that provides Solid lint rules.

This plugin registers custom lint rules and enables them to be executed by the Dart analyzer during code analysis.

Inheritance
  • Object
  • Plugin
  • SolidLintsPlugin

Constructors

SolidLintsPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
A user-visible name for this plugin, used for error-reporting and insights-reporting purposes.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(PluginRegistry registry) → void
Registers analysis rules, quick fixes, and assists.
override
shutDown() FutureOr<void>
inherited
start() FutureOr<void>
Initializes any necessary start-up state that is required for this plugin to run.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited