plugin top-level property

SolidLintsPlugin plugin
final

The entry point for the Solid Lints analyser server plugin.

This plugin integrates custom lint rules into the Dart analysis server, allowing them to run during static analysis.

Implementation

final plugin = SolidLintsPlugin();